==> larus_board-0.9.9.zip: larus_board-0.9.9/lb_private/lang/en/core.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'accept'=>'Accept',
'access_denied'=>'Access Denied',
'action_has_not_committed_transaction'=>'Proccess aborted due to open transaction!',
'all'=>'all',
'allow'=>'Allow',
'all_times_are'=>'All times are',
'an_error_occured'=>'An error has occured',
'ap_exec'=>'Executives',
'ap_mod'=>'Moderators',
'ap_owner'=>'Owner',
'ascending'=>'Ascending',
'back_to_topic'=>' Back to Topic',
'be_careful_on_external_content'=>'Be careful on external content!',
'by'=>'by',
'clear'=>'Clear',
'click_here_for_redirection'=>'Please click here, if you are not forwarded automatically...',
'create_new_user_account'=>'Create New User',
'currently_none'=>'currently none',
'date'=>'Date',
'day'=>'Day',
'days'=>'Days',
'default'=>'default',
'delete'=>'Delete',
'deny'=>'Deny',
'descending'=>'Descending',
'disable'=>'Disable',
'edit'=>'Edit',
'enable'=>'Enable',
'executive_panel'=>'Executive Area',
'expired'=>'expired',
'explain_error_message'=>'Usually this happens because you are not logged with your user account. Another reason may be that your authentication became invalid. Then you should reload the page in your browser. The forum will ask you to renew it. Last but not least you may simply just have no permission to access that given area.',
'fail'=>'Failure',
'file_not_found'=>'File Not Found',
'fun_message_1'=>'You forgot to say the "MAGICAL WORD"...',
'fun_message_2'=>'I think I am bothered of you...',
'fun_message_3'=>'Can`t you see I am busy?',
'fun_message_4'=>'I beg your pardon?',
'fun_message_5'=>'No, I am not going to do that!',
'fun_message_6'=>'The same procedure as every year, James!',
'fun_message_7'=>'Do not disturb me now, you *"\$/(=!',
'fun_message_8'=>'*sigh*',
'go_one_step_back'=>'Please click here to go one step back...',
'group'=>'User Group',
'group_alias_exec'=>'Executive',
'group_alias_guest'=>'Unregistered',
'group_alias_mod'=>'Moderator',
'group_alias_root'=>'Super-User',
'group_alias_user'=>'Member',
'guest'=>'Guest',
'help'=>'Help',
'hidden'=>'Hidden',
'home'=>'Home',
'hour'=>'Hour',
'hours'=>'Hours',
'imprint_and_privacy'=>'Imprint and Privacy Statement',
'invalid_form_input'=>'Please verify your inputs as some were rejected!',
'javascript_hint'=>'Please enable <em>Javascript</em> in your browser to get full usability on our forums! Basic functions can be used without it, if you are concerned about your security. To enable it, please have a look at your browser manual how to do this. Usually it can be found in "Options" or "Settings".',
'last_reply'=>'Last Reply',
'login'=>'Login',
'login_valid_for'=>'Authentication Time Remaining',
'logout'=>'Logout',
'mail_address'=>'E-Mail Address',
'member_list'=>'Member List',
'message'=>'Message',
'minute'=>'Minute',
'minutes'=>'Minutes',
'moderation_panel'=>'Moderation Area',
'month'=>'Month',
'must_not_alter_foreign_entry'=>'You are not allowed to alter foreign datasets!',
'my_profile'=>'My Profile',
'name'=>'Name',
'new'=>'New',
'no'=>'no',
'none'=>'none',
'no_members_found'=>'No members are found on your query...',
'no_valid_id'=>'Your selected ID is invalid!',
'on'=>'on',
'options'=>'Options',
'order_by'=>'Order',
'overview'=>'Overview',
'page'=>'Page',
'password'=>'Password',
'pending_requests'=>'Current pending requests',
'please_confirm_reverting'=>'Please confirm you really want to revert to this revision?',
'please_confirm_your_selection'=>'Please confirm your request to irrevocably delete the selected items...',
'post_count'=>'Posts',
'post_count_hint'=>'This value is a best guess and may differ from reality.',
'prefix_announcement'=>'Announcement',
'prefix_executive_only'=>'To Executive only',
'prefix_moderator_only'=>'To Moderator only',
'prefix_staff_only'=>'To Staff only',
'prefix_support_request'=>'Support Request',
'preview'=>'Preview',
'profile_view'=>'Profile View',
'query_for'=>'Search Users',
'rating'=>'Rating',
'really_logout'=>'Would you really like to logout?',
'redirection'=>'Redirection',
'register'=>'Register',
'registration_date'=>'Registered Since',
'replies'=>'Replies',
'requires_elevated_permissions'=>'You must be in a user group having elevated permissions (executive/moderator) to do this.',
'running_action_denied_by_acl'=>'You are not allowed to perform this action as you were rejected by access control list',
'search'=>'Search',
'search_posts_by_user'=>'Find Postings',
'second'=>'Second',
'seconds'=>'Seconds',
'select_user'=>'Select User',
'sort_by'=>'Sort By',
'stage'=>'Do what?',
'standard_panel'=>'User Area',
'subject'=>'Subject',
'submit'=>'Submit',
'success'=>'Success',
'tags'=>'Tags',
'to'=>'to',
'today'=>'Today',
'total'=>'Total',
'transaction_number_invalid'=>'You have not pass the correct transaction number!',
'user'=>'User',
'username'=>'Username',
'user_request'=>'User Request',
'visible'=>'Visible',
'warning_high'=>'You violated our rules multiple times and reached the highest warning level!',
'warning_level'=>'Warning Level',
'warning_level_high'=>'Causes severe trouble by violating rules',
'warning_level_low'=>'Has been warned once',
'warning_level_medium'=>'Needs attention on further misbehaviour',
'warning_level_none'=>'No warnings issued so far',
'welcome'=>'Welcome',
'year'=>'Year',
'yes'=>'yes',
'yesterday'=>'Yesterday'
);
?>

==> larus_board-0.9.16.zip: larus_board-0.9.16/lb_private/lang/en/core.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'accept'=>'Accept',
'access_denied'=>'Access Denied',
'action_has_not_committed_transaction'=>'Proccess aborted due to open transaction!',
'all'=>'all',
'allow'=>'Allow',
'all_times_are'=>'All times are',
'an_error_occured'=>'An error has occured',
'ap_exec'=>'Executives',
'ap_mod'=>'Moderators',
'ap_owner'=>'Owner',
'ascending'=>'Ascending',
'back_to_topic'=>' Back to Topic',
'be_careful_on_external_content'=>'Be careful on external content!',
'by'=>'by',
'clear'=>'Clear',
'click_here_for_redirection'=>'Please click here, if you are not forwarded automatically...',
'create_new_user_account'=>'Create New User',
'currently_none'=>'currently none',
'date'=>'Date',
'day'=>'Day',
'days'=>'Days',
'default'=>'default',
'delete'=>'Delete',
'delete_not_confirmed'=>'You did not confirm to delete.',
'deny'=>'Deny',
'descending'=>'Descending',
'disable'=>'Disable',
'edit'=>'Edit',
'embed_object_flash'=>'Flash Movie',
'embed_object_unknown'=>'Unknown',
'embed_object_vector'=>'Vector Image',
'enable'=>'Enable',
'executive_panel'=>'Executive Area',
'expired'=>'expired',
'explain_error_message'=>'Usually this happens because you are not logged with your user account. Another reason may be that your authentication became invalid. Then you should reload the page in your browser. The forum will ask you to renew it. Last but not least you may simply just have no permission to access that given area.',
'fail'=>'Failure',
'file_not_found'=>'File Not Found',
'fun_message_1'=>'You forgot to say the "MAGICAL WORD"...',
'fun_message_2'=>'I think I am bothered of you...',
'fun_message_3'=>'Can`t you see I am busy?',
'fun_message_4'=>'I beg your pardon?',
'fun_message_5'=>'No, I am not going to do that!',
'fun_message_6'=>'The same procedure as every year, James!',
'fun_message_7'=>'Do not disturb me now, you *"\$/(=!',
'fun_message_8'=>'*sigh*',
'go_one_step_back'=>'Please click here to go one step back...',
'group'=>'User Group',
'group_alias_exec'=>'Executive',
'group_alias_guest'=>'Unregistered',
'group_alias_mod'=>'Moderator',
'group_alias_root'=>'Super-User',
'group_alias_user'=>'Member',
'guest'=>'Guest',
'help'=>'Help',
'hidden'=>'Hidden',
'home'=>'Home',
'hour'=>'Hour',
'hours'=>'Hours',
'imprint_and_privacy'=>'Imprint and Privacy Statement',
'invalid_form_input'=>'Please verify your inputs as some were rejected!',
'javascript_hint'=>'Please enable <em>Javascript</em> in your browser to get full usability on our forums! Basic functions can be used without it, if you are concerned about your security. To enable it, please have a look at your browser manual how to do this. Usually it can be found in "Options" or "Settings".',
'last_reply'=>'Last Reply',
'login'=>'Login',
'login_valid_for'=>'Authentication Time Remaining',
'logout'=>'Logout',
'mail_address'=>'E-Mail Address',
'member_list'=>'Member List',
'message'=>'Message',
'minute'=>'Minute',
'minutes'=>'Minutes',
'moderation_panel'=>'Moderation Area',
'month'=>'Month',
'must_not_alter_foreign_entry'=>'You are not allowed to alter foreign datasets!',
'my_profile'=>'My Profile',
'name'=>'Name',
'new'=>'New',
'no'=>'no',
'none'=>'none',
'no_members_found'=>'No members are found on your query...',
'no_valid_id'=>'Your selected ID is invalid!',
'on'=>'on',
'options'=>'Options',
'order_by'=>'Order',
'overview'=>'Overview',
'page'=>'Page',
'password'=>'Password',
'pending_requests'=>'Current pending requests',
'please_confirm_reverting'=>'Please confirm you really want to revert to this revision?',
'please_confirm_your_selection'=>'Please confirm your request to irrevocably delete the selected items...',
'post_count'=>'Posts',
'post_count_hint'=>'This value is a best guess and may differ from reality.',
'prefix_announcement'=>'Announcement',
'prefix_executive_only'=>'To Executive only',
'prefix_moderator_only'=>'To Moderator only',
'prefix_staff_only'=>'To Staff only',
'prefix_support_request'=>'Support Request',
'preview'=>'Preview',
'profile_view'=>'Profile View',
'query_for'=>'Search Users',
'rating'=>'Rating',
'really_logout'=>'Would you really like to logout?',
'redirection'=>'Redirection',
'register'=>'Register',
'registration_date'=>'Registered Since',
'replies'=>'Replies',
'requires_elevated_permissions'=>'You must be in a user group having elevated permissions (executive/moderator) to do this.',
'running_action_denied_by_acl'=>'You are not allowed to perform this action as you were rejected by access control list',
'search'=>'Search',
'search_posts_by_user'=>'Find Postings',
'second'=>'Second',
'seconds'=>'Seconds',
'select_color'=>'Select Color',
'select_user'=>'Select User',
'show_advanced_options'=>'Show advanced options',
'sort_by'=>'Sort By',
'stage'=>'Do what?',
'standard_panel'=>'User Area',
'subject'=>'Subject',
'submit'=>'Submit',
'success'=>'Success',
'tags'=>'Tags',
'to'=>'to',
'today'=>'Today',
'total'=>'Total',
'transaction_number_invalid'=>'You have not pass the correct transaction number!',
'user'=>'User',
'username'=>'Username',
'user_request'=>'User Request',
'visible'=>'Visible',
'warning_high'=>'You violated our rules multiple times and reached the highest warning level!',
'warning_level'=>'Warning Level',
'warning_level_high'=>'Causes severe trouble by violating rules',
'warning_level_low'=>'Has been warned once',
'warning_level_medium'=>'Needs attention on further misbehaviour',
'warning_level_none'=>'No warnings issued so far',
'welcome'=>'Welcome',
'year'=>'Year',
'yes'=>'yes',
'yesterday'=>'Yesterday'
);
?>
